/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                    Java Language Motus SDK, Version 6.0                    */
/*                    Copyright 2022, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2022 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Heave offset */
public class ANPacket194
{
	public static final int LENGTH = 49;

	public Boolean permanent;
	/* Units: metres */
	public float[][] referencePointOffsets;

	public ANPacket194()
	{
		referencePointOffsets = new float[4][3];
	}

	public ANPacket194(ANPacket packet)
	{
		permanent = packet.data[0] != 0;
		referencePointOffsets = new float[4][3];
		referencePointOffsets[0][0] = TypeConversion.bytesToFloat(packet.data, 1);
		referencePointOffsets[0][1] = TypeConversion.bytesToFloat(packet.data, 5);
		referencePointOffsets[0][2] = TypeConversion.bytesToFloat(packet.data, 9);
		referencePointOffsets[1][0] = TypeConversion.bytesToFloat(packet.data, 13);
		referencePointOffsets[1][1] = TypeConversion.bytesToFloat(packet.data, 17);
		referencePointOffsets[1][2] = TypeConversion.bytesToFloat(packet.data, 21);
		referencePointOffsets[2][0] = TypeConversion.bytesToFloat(packet.data, 25);
		referencePointOffsets[2][1] = TypeConversion.bytesToFloat(packet.data, 29);
		referencePointOffsets[2][2] = TypeConversion.bytesToFloat(packet.data, 33);
		referencePointOffsets[3][0] = TypeConversion.bytesToFloat(packet.data, 37);
		referencePointOffsets[3][1] = TypeConversion.bytesToFloat(packet.data, 41);
		referencePointOffsets[3][2] = TypeConversion.bytesToFloat(packet.data, 45);
	}

	public ANPacket toANPacket() throws IndexOutOfBoundsException
	{	
		ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_REFERENCE_POINT_OFFSETS);
		packet.data[0] = (byte) (permanent ? 1 : 0);
		TypeConversion.floatToBytes(packet.data, 1, referencePointOffsets[0][0]);
		TypeConversion.floatToBytes(packet.data, 5, referencePointOffsets[0][1]);
		TypeConversion.floatToBytes(packet.data, 9, referencePointOffsets[0][2]);
		TypeConversion.floatToBytes(packet.data, 13, referencePointOffsets[1][0]);
		TypeConversion.floatToBytes(packet.data, 17, referencePointOffsets[1][1]);
		TypeConversion.floatToBytes(packet.data, 21, referencePointOffsets[1][2]);
		TypeConversion.floatToBytes(packet.data, 25, referencePointOffsets[2][0]);
		TypeConversion.floatToBytes(packet.data, 29, referencePointOffsets[2][1]);
		TypeConversion.floatToBytes(packet.data, 33, referencePointOffsets[2][2]);
		TypeConversion.floatToBytes(packet.data, 37, referencePointOffsets[3][0]);
		TypeConversion.floatToBytes(packet.data, 41, referencePointOffsets[3][1]);
		TypeConversion.floatToBytes(packet.data, 45, referencePointOffsets[3][2]);
		return packet;
	}
}
